@@ -1,6 +1,8 @@
 //! Displays an OS-specific message dialog.
 //! Display OS-specific dialogs in Windows environment, and GTK dialogs in Linux environment.
 
+use crate::window::Frame;
+
 #[cfg(windows)]
 pub struct MessageBox {
     /// Message to be displayed
@@ -53,7 +55,7 @@ impl MessageBox {
     ///     MessageBox::new("Hello NXUI!".to_string(),"This is a test".to_string(),DIALOGSTYLE_INFORMATION,BUTTONSTYLE_OK).show();
     /// }
     /// ```
-    pub fn show(&self) -> windows_sys::Win32::UI::WindowsAndMessaging::MESSAGEBOX_RESULT {
+    pub fn show(&self,frame: Frame) -> windows_sys::Win32::UI::WindowsAndMessaging::MESSAGEBOX_RESULT {
         unsafe {
             use windows_sys::{
                 Win32::Foundation::*, Win32::System::Threading::*,
@@ -65,7 +67,7 @@ impl MessageBox {
             CloseHandle(event);
 
             let result = MessageBoxA(
-                0,
+                frame.get_window(),
                 self.message.as_ptr(),
                 self.title.as_ptr(),
                 self.style | self.button_style,
@@ -103,7 +105,7 @@ impl MessageBox {
     ///     MessageBox::new("Hello NXUI!".to_string(),"This is a test".to_string(),DIALOGSTYLE_INFORMATION,BUTTONSTYLE_OK).show();
     /// }
     /// ```
-    pub fn show(&self) -> gtk::ResponseType {
+    pub fn show(&self,frame: Frame) -> gtk::ResponseType {
         use gtk::prelude::*;
         gtk::init().expect("Failed to initialize gtk.");
         let window = gtk::Window::new(gtk::WindowType::Toplevel);
