@@ -75,7 +75,7 @@ impl Frame {
         use windows_sys::Win32::Foundation::RECT;
         use windows_sys::Win32::UI::WindowsAndMessaging::*;
         unsafe {
-            let mut rect = &mut RECT {
+            let rect = &mut RECT {
                 left: 0,
                 top: 0,
                 right: 0,
@@ -167,7 +167,7 @@ pub trait Application {
     }
 
     /// Processing at application startup (optional)
-    fn startup(&self,storage: Storage) {
+    fn startup(&self,_storage: Storage) {
     }
 
     /// Writing UI processes and events
